<?php
/**
 * This file is required from FortGuard\Admin -> createView()
 */

use FortGuard\FortGuard as FortGuard;

if (!defined('ABSPATH'))
    die;

$apiKey = FortGuard::getAPIKey();
$spamScore = FortGuard::getSpamScore();
$model = FortGuard::getModel();
$sentiments = FortGuard::getSentiments();
$countries = FortGuard::getCountries();
$languages = FortGuard::getLanguages();
$countryExcludeInclude = FortGuard::getCountryExcludeInclude();
$contetSpamToggle = FortGuard::getContentSpamToggle();
$locationSpamToggle = FortGuard::getLocationSpamToggle();
$languageSpamToggle = FortGuard::getLanguageSpamToggle();
$sentimentSpamToggle = FortGuard::getSentimentSpamToggle();
$languageExcludeInclude = FortGuard::getLanguageExcludeInclude();
$selectedOption = 'selected="selected"';
?>


<div id="fortguard-admin">

    <div class="wrap">
        <img src="<?php echo esc_url(FORTGUARD_DIR_URL) ?>static/fortguard-logo.png" width="40" class="fortguard-title-img">
        <span class="fortguard-title">FortGuard Plugin</span>
    </div>

    <div class="wrap">
        <div class="fortguard-native-panel">
            

            <div class="dual-item">
                
                <div class="dual-item-left"><?php echo esc_html__('FortGuard API Key', 'fortguard') ?></div>
                
                <div class="dual-item-right">
                    
                    <input type="text" name="fortguard-api-key" id="fortguard-api-key-input" class="input-item" value="<?php echo esc_attr($apiKey ? $apiKey : '') ?>">

                    <?php if (!$apiKey) : ?>

                        <div class="fortguard-message">
                            <strong>
                                <?php echo esc_html__('Important!', 'fortguard') ?>
                            </strong>
                            <?php echo esc_html__('Add your FortGuard API key to configure FortGuard with Wordpress. Find your API Key in', 'fortguard') ?> 
                            <a 
                                href="https://fortguard.io/console" 
                                class="console-link"
                                target="_blank">
                                <?php echo esc_html__('FortGuard Console.', 'fortguard') ?>
                            </a>
                        </div>

                    <?php else : ?>
                            
                            <p class="help"><?php echo esc_html__('Visit', 'fortguard') ?>
                                <a 
                                    target="_blank" 
                                    href="https://fortguard.io/console">
                                    <?php echo esc_html__('FortGuard Console', 'fortguard') ?>
                                </a>
                            </p>
                    <?php endif; ?>
                    
                </div>
            </div>


            <div class="dual-item">
					
                <div class="dual-item-left"><?php echo esc_html__('Model', 'fortguard') ?></div>

                <div class="dual-item-right">
                    <select id="fortguard-model-select">
                        <option 
                            value="gpt-3.5" 
                            <?php echo esc_attr($model === "gpt-3.5" ? $selectedOption : '') ?>
                        ><?php echo esc_html__('GPT 3.5', 'fortguard') ?></option>
                        <option 
                            value="gpt-4"
                            <?php echo esc_attr($model === "gpt-4" ? $selectedOption : '') ?>
                        ><?php echo esc_html__('GPT 4', 'fortguard') ?></option>
                    </select>
                </div>
            </div>

            <div class="dual-item">
                
                <div class="dual-item-left"><?php echo esc_html__('Spam by Content', 'fortguard') ?></div>

                <div class="dual-item-right">
                    <label class="switch">
                        <input type="checkbox" id="toggle-content-spam" name="toggle-content-spam" <?php echo $contetSpamToggle === 1 ? 'checked' : ''; ?>>
                        <span class="slider"></span>
                    </label>
                </div>
            </div>

            <div class="dual-item" id="content-spam-container">
                
                <div class="dual-item-left">
                    <?php echo esc_html__('Spam Score (1-5)', 'fortguard') ?>
                </div>

                <div class="dual-item-right">
                    <div>
                        <input type="range" id="spam-score" name="spam-score" min="1" max="5" value="<?php echo esc_attr($spamScore ? $spamScore : 3); ?>" />
                        <input type="text" id="spam-score-text" value="<?php echo esc_attr($spamScore ? $spamScore : 3); ?>" disabled>
                    </div>
                    <div>
                        <?php echo esc_html__('Selected value and upwards will be considered as spam', 'fortguard') ?>
                    </div>
                </div>
            </div>

            <div class="dual-item">
                
                <div class="dual-item-left"><?php echo esc_html__('Spam by Location', 'fortguard') ?></div>

                <div class="dual-item-right">
                    <label class="switch">
                        <input type="checkbox" id="toggle-location-spam" name="toggle-location-spam" <?php echo $locationSpamToggle === 1 ? 'checked' : ''; ?>>
                        <span class="slider"></span>
                    </label>
                </div>
            </div>

            <div class="dual-item" id="location-spam-container">
                
                <div class="dual-item-left"><?php echo esc_html__('Countries', 'fortguard') ?></div>

                <div class="dual-item-right">

                    <input type="text" id="country_selector" name="countries" class="input-item" value="<?php echo esc_attr($countries ? $countries : '') ?>"/>


                    <div>
                        <label for="exclude">
                            <input type="radio" id="exclude" name="exclude-include" value="exclude" <?php echo $countryExcludeInclude === "include" ? '' : 'checked'; ?>>
                            Exclude
                        </label>
                        <label for="include">
                            <input type="radio" id="include" name="exclude-include" value="include" <?php echo $countryExcludeInclude === "include" ? 'checked' : ''; ?>>
                            Include
                        </label>
                    </div>
                </div>
            </div>

            <div class="dual-item">
                
                <div class="dual-item-left"><?php echo esc_html__('Spam by Language', 'fortguard') ?></div>

                <div class="dual-item-right">
                    <label class="switch">
                        <input type="checkbox" id="toggle-language-spam" name="toggle-language-spam" <?php echo $languageSpamToggle === 1 ? 'checked' : ''; ?>>
                        <span class="slider"></span>
                    </label>
                </div>
            </div>

            <div class="dual-item" id="language-spam-container">
                
                <div class="dual-item-left"><?php echo esc_html__('Languages', 'fortguard') ?></div>

                <div class="dual-item-right">

                    <input type="text" id="language_selector" name="languages" class="input-item" value="<?php echo esc_attr($languages ? $languages : '') ?>"/>


                    <div>
                        <label for="language-exclude">
                            <input type="radio" id="language-exclude" name="language-exclude-include" value="exclude" <?php echo $languageExcludeInclude === "include" ? '' : 'checked'; ?>>
                            Exclude
                        </label>
                        <label for="language-include">
                            <input type="radio" id="language-include" name="language-exclude-include" value="include" <?php echo $languageExcludeInclude === "include" ? 'checked' : ''; ?>>
                            Include
                        </label>
                    </div>
                </div>
            </div>

            <div class="dual-item">
                
                <div class="dual-item-left"><?php echo esc_html__('Spam by Sentiment', 'fortguard') ?></div>

                <div class="dual-item-right">
                    <label class="switch">
                        <input type="checkbox" id="toggle-sentiment-spam" name="toggle-sentiment-spam" <?php echo $sentimentSpamToggle === 1 ? 'checked' : ''; ?>>
                        <span class="slider"></span>
                    </label>
                </div>
            </div>

            <div class="dual-item" id="sentiment-spam-container">
                
                <div class="dual-item-left"><?php echo esc_html__('Sentiments', 'fortguard') ?></div>

                <div class="dual-item-right">
                    <input placeholder='POSITIVE, NEGATIVE, NEUTRAL' type="text" name="sentiments" id="sentiments-input" class="input-item" value="<?php echo esc_attr($sentiments ? $sentiments : '') ?>">

                    <div><?php echo esc_html__('Comma separated list of sentiments. You can include any sentiment which is not suggested in the dropdown.', 'fortguard') ?></div>

                </div>
            </div>

            <div class="save-button-view">
				<span 
					class="button-filled" 
					onclick="fortguard.saveSettings()">
					<?php echo $apiKey ? esc_html__('CHANGE', 'fortguard') : esc_html__('SAVE', 'fortguard') ?>
				</span>
			</div>

        </div>
    </div>
</div>